package com.iwangding.scsp_mobile_demo;

import androidx.appcompat.app.AppCompatActivity;

import android.net.wifi.WifiManager;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Button;
import android.widget.TextView;

import com.iwangding.basis.util.LogUtil;
import com.iwangding.scsp.ISCSP;
import com.iwangding.scsp.SCSPConfig;
import com.iwangding.scsp.speedtest.OnSpeedTestListener;
import com.iwangding.scsp.speedtest.data.PrepareData;
import com.iwangding.scsp.speedtest.data.SpeedData;
import com.iwangding.ssmp.function.download.data.DownloadData;
import com.iwangding.ssmp.function.node.data.NodePingData;
import com.iwangding.ssmp.function.ping.OnPingListener;
import com.iwangding.ssmp.function.ping.data.PingData;
import com.iwangding.ssmp.function.upload.data.UploadData;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStream;
import java.io.InputStreamReader;
import java.net.InetAddress;

public class MainActivity extends AppCompatActivity implements View.OnClickListener {

    private ISCSP scsp;
    private TextView text;
    private Button startSpeedTestBtn, stopSpeedTestBtn;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        text = findViewById(R.id.text_info);
        startSpeedTestBtn = findViewById(R.id.btn_start_speed);
        startSpeedTestBtn.setOnClickListener(this);

        stopSpeedTestBtn = findViewById(R.id.btn_stop_speed);
        stopSpeedTestBtn.setOnClickListener(this);

        scsp = ISCSP.newInstance();
    }

    private void startSpeedTest() {
        SCSPConfig config = new SCSPConfig.Builder().build();

        if (scsp != null) scsp.startSpeedTest(this, config, null, new OnSpeedTestListener() {
            @Override
            public void onSpeedTestStart() {
                text.setText("----------开始网络测速----------");
            }

            @Override
            public void onSpeedTestPrepareStart() {
                text.append("\n准备网络测速配置");
            }

            @Override
            public void onSpeedTestPrepareSuccess(PrepareData prepareData) {
                text.append("\n网络测速配置完成：" + prepareData);
            }

            @Override
            public void onSpeedTestPingStart() {
                text.append("\n开始Ping测速");
            }

            @Override
            public void onSpeedTestPingSuccess(PingData data) {
                text.append("\nPing测速成功：" + data);
            }

            @Override
            public void onSpeedTestDownloadStart() {
                text.append("\n开始下载测速");
            }

            @Override
            public void onSpeedTestDownloadProcess(long speed) {
                text.append("\n下载测速中：" + speed);
            }

            @Override
            public void onSpeedTestDownloadSuccess(DownloadData data) {
                text.append("\n下载测速成功：" + data);
            }

            @Override
            public void onSpeedTestUploadStart() {
                text.append("\n开始上传测速");
            }

            @Override
            public void onSpeedTestUploadProcess(long speed) {
                text.append("\n上传测速中：" + speed);
            }

            @Override
            public void onSpeedTestUploadSuccess(UploadData data) {
                text.append("\n上传测速成功：" + data);
            }

            @Override
            public void onSpeedTestFail(int code, String msg) {
                text.append("\n网络测速失败：code：" + code + " msg：" + msg);
                startSpeedTestBtn.setClickable(true);
            }

            @Override
            public void onSpeedTestFinish(SpeedData speedData) {
                text.append("\n----------网络测速完成----------");
                text.append("\n网络测速结果：" + speedData);
                startSpeedTestBtn.setClickable(true);
            }

            @Override
            public void onSpeedTestCancel() {
                text.append("\n取消网络测速");
            }
        });
    }

    private void stopSpeedTest() {
        if (scsp != null) scsp.stopSpeedTest();
    }

    @Override
    public void onClick(View v) {
        switch (v.getId()) {
            case R.id.btn_start_speed:
                startSpeedTestBtn.setClickable(false);
                startSpeedTest();
                break;
            case R.id.btn_stop_speed:
                startSpeedTestBtn.setClickable(true);
                stopSpeedTest();
                break;
        }
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (scsp != null) {
            scsp.release();
            scsp = null;
        }
    }
}
